@@ -2,7 +2,7 @@ def CustomProperty(atr, types):
     if isinstance(atr, types):
         return atr
     else:
-        raise AttributeError(f"Use only {types}")
+        raise TypeError(f"Use only {types}")
 
 def StrProperty(atr):
     return CustomProperty(atr, str)
